@@ -4,13 +4,13 @@ from typing import List, Union
 
 try:
     # Python 3.8+: https://peps.python.org/pep-0586
-    from typing import Literal  # type: ignore[attr-defined]
+    from typing import Literal
 except ImportError:
-    from typing_extensions import Literal  # type: ignore[misc, assignment]
+    from typing_extensions import Literal  # type: ignore[assignment]
 
 try:
     # Python 3.10+: https://www.python.org/dev/peps/pep-0484/
-    from typing import TypeAlias  # type: ignore[attr-defined]
+    from typing import TypeAlias
 except ImportError:
     from typing_extensions import TypeAlias
 
